@@ -9,6 +9,8 @@ class Stream:
         self.lines = [line + ' ' for line in self.lines]
         self.n = 0
         self.pos = 0
+        self.last_peak_pos = -1
+        self._pass_forward()
 
     def peek(self, *args: Union[tokens.Token, Type[tokens.Token]]):
         """Reads several tokens from stream"""
@@ -16,6 +18,7 @@ class Stream:
             return None
         line = self.lines[self.n]
         pos = self.pos
+        self.last_peak_pos = -1  # prevent step() after failed peek()
         read_tokens = []
         for arg in args:
             if isinstance(arg, tokens.Token):
@@ -23,6 +26,7 @@ class Stream:
             else:
                 token_type = arg
 
+            # skip empty line ending
             while pos < len(line) and line[pos].isspace():
                 pos += 1
             if pos >= len(line):
@@ -30,8 +34,10 @@ class Stream:
 
             try:
                 length, token = token_type.read(line[pos:])
+                # mb: pass full stream to token. (This will allow multiline string parsing)
             except tokens.TokenError as e:
                 raise StreamError(self.n, pos, e)
+
             if token is None:
                 return None
             if isinstance(arg, tokens.Token) and token != arg:
@@ -45,7 +51,11 @@ class Stream:
         return read_tokens
 
     def step(self):
+        assert self.last_peak_pos > 0, "step() called before peaking any Token"
         self.pos = self.last_peak_pos
+        self._pass_forward()
+
+    def _pass_forward(self):
         while self and (
                 self.pos >= len(self.lines[self.n]) or
                 self.lines[self.n][self.pos:].isspace() or
@@ -71,4 +81,4 @@ class StreamError(Exception):
         self.msg = msg
 
     def __str__(self):
-        return f"{self.line + 1}:{self.pos}: {self.msg}"
+        return f"{self.line + 1}:{self.pos + 1}: {self.msg}"
